package com.example.bookshelf;

import android.app.ListActivity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.database.Cursor;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.ContextMenu;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;
import android.widget.AdapterView.AdapterContextMenuInfo;

public class BookshelfActivity extends ListActivity implements
		SharedPreferences.OnSharedPreferenceChangeListener {

	protected static final int REQUEST_ADD_BOOK = 0;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		PreferenceManager.getDefaultSharedPreferences(this)
				.registerOnSharedPreferenceChangeListener(this);

		updateList();

		registerForContextMenu(getListView());
	}

	@Override
	public void onDestroy() {
		PreferenceManager.getDefaultSharedPreferences(this)
				.unregisterOnSharedPreferenceChangeListener(this);
	}

	protected void updateList() {
		String orderBy = SettingsActivity.getOrderByColumn(this);
		boolean desc = SettingsActivity.getOrderDesc(this);

		Database db = new Database(this);
		Cursor c = db.getBooks(orderBy, desc);

		BookshelfAdapter adapter = new BookshelfAdapter(this, c, 0);

		setListAdapter(adapter);

		db.close();
	}

	public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
			String key) {
		if (key.equals(SettingsActivity.ORDER_BY)
				|| key.equals(SettingsActivity.DESC)) {
			updateList();
		}
	}

	@Override
	public void onCreateContextMenu(ContextMenu menu, View v,
			ContextMenu.ContextMenuInfo menuInfo) {
		super.onCreateContextMenu(menu, v, menuInfo);
		getMenuInflater().inflate(R.menu.context, menu);
	}

	@Override
	public boolean onContextItemSelected(MenuItem item) {
		AdapterContextMenuInfo info = (AdapterContextMenuInfo) item.getMenuInfo();
		switch (item.getItemId()) {
		case R.id.delete:
			Database db = new Database(this);
			if (db.deleteBook(info.id)) {
				Toast.makeText(this, R.string.deleted, Toast.LENGTH_SHORT)
						.show();
				updateList();
			} else {
				Toast.makeText(this, R.string.not_deleted, Toast.LENGTH_SHORT)
						.show();
			}
			return true;
		default:
			return super.onContextItemSelected(item);
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.options_menu, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		Intent i;
		switch (item.getItemId()) {
		case R.id.add_book:
			i = new Intent(this, AddBookActivity.class);
			startActivityForResult(i, REQUEST_ADD_BOOK);
			return true;
		case R.id.preferences:
			i = new Intent(this, SettingsActivity.class);
			startActivity(i);
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == REQUEST_ADD_BOOK && resultCode == RESULT_OK)
			updateList();

		super.onActivityResult(requestCode, resultCode, data);
	}
}