package com.example.bookshelf;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class Database {
	protected static final String DATABASE_NAME = "bookshelf";
	protected static final int DATABASE_VERSION = 1;

	protected static final String TB_NAME = "books";

	public static final String COLUMN_ID = "_id";
	public static final String COLUMN_TITLE = "title";
	public static final String COLUMN_AUTHOR = "author";
	public static final String COLUMN_RATING = "rating";

	public static final String[] columns = { COLUMN_ID, COLUMN_TITLE,
			COLUMN_AUTHOR, COLUMN_RATING };

	private SQLiteOpenHelper openHelper;

	static class DatabaseHelper extends SQLiteOpenHelper {

		DatabaseHelper(Context context) {
			super(context, DATABASE_NAME, null, DATABASE_VERSION);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
			db.execSQL("CREATE TABLE " + TB_NAME + " (" + COLUMN_ID
					+ " INTEGER PRIMARY KEY," + COLUMN_TITLE
					+ " TEXT NOT NULL," + COLUMN_AUTHOR + " TEXT NOT NULL,"
					+ COLUMN_RATING + " INTEGER NOT NULL" + ");");
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
			db.execSQL("DROP TABLE IF EXISTS " + TB_NAME);
			onCreate(db);
		}
	}

	public Database(Context ctx) {
		openHelper = new DatabaseHelper(ctx);
	}

	public Cursor getBooks(String orderBy, boolean desc) {
		SQLiteDatabase db = openHelper.getReadableDatabase();
		return db.query(TB_NAME, columns, null, null, null, null, orderBy
				+ (desc ? " DESC" : " ASC"));
	}

	public boolean deleteBook(long id) {
		SQLiteDatabase db = openHelper.getWritableDatabase();
		String[] selectionArgs = { String.valueOf(id) };

		int deletedCount = db.delete(TB_NAME, COLUMN_ID + "= ?", selectionArgs);
		db.close();
		return deletedCount > 0;
	}

	public long addBook(String title, String author, int rating) {
		SQLiteDatabase db = openHelper.getWritableDatabase();

		// Rating smí být jen z rozmení 0 - 4
		rating = Math.max(0, Math.min(rating, 4));

		ContentValues values = new ContentValues();
		values.put(COLUMN_TITLE, title);
		values.put(COLUMN_AUTHOR, author);
		values.put(COLUMN_RATING, rating);

		long id = db.insert(TB_NAME, null, values);
		db.close();
		return id;
	}

	public void close() {
		openHelper.close();
	}
}
